# Copyright (c) 2022, 2024 DomainTools LLC
# Copyright (c) 2015-2016, 2018-2019, 2021 by Farsight Security, Inc.
# This work is unpublished, and unauthorized reproduction is prohibited.
# DomainTools, LLC owns all rights to this work and intends that
# it be held confidential, preserved as a trade secret, and protected as
# an unpublished copyrighted work.

import urllib.request, urllib.error, urllib.parse
import http.client
import logging
import socket
import ssl
logger = logging.getLogger(__name__)

ca_file = '/etc/ssl/certs/ca-certificates.crt'
keyfile = None
certfile = None
ciphers = 'EECDH+ECDSA+AESGCM:EECDH+aRSA+AESGCM:EECDH+ECDSA+SHA384:EECDH+ECDSA+SHA256:EECDH+aRSA+SHA384:EECDH+aRSA+SHA256:!EECDH+aRSA+RC4:EECDH:EDH+aRSA:!RC4:!aNULL:!eNULL:!LOW:!3DES:!MD5:!EXP:!PSK:!SRP:!DSS:@STRENGTH'

class HTTPSConnection(http.client.HTTPConnection):
    default_port = http.client.HTTPS_PORT

    def __init__(self, *args, **kwargs):
        http.client.HTTPConnection.__init__(self, *args, **kwargs)

    def connect(self):
        try:
            sock = socket.create_connection((self.host, self.port), self.timeout, self.source_address)
        except socket.error as e:
            raise urllib.error.URLError(e)
        if self._tunnel_host:
            self.sock = sock
            self._tunnel()
        try:
            self.sock = ssl.wrap_socket(sock, ssl_version=ssl.PROTOCOL_TLS,
                    ca_certs=ca_file, cert_reqs=ssl.CERT_REQUIRED,
                    keyfile=keyfile, certfile=certfile, ciphers=ciphers)
        except (ssl.SSLError, ssl.CertificateError, socket.error) as e:
            raise urllib.error.URLError(e)

class HTTPSHandler(urllib.request.HTTPSHandler):
    def https_open(self, req):
        return self.do_open(HTTPSConnection, req)
    handler_order = urllib.request.HTTPSHandler.handler_order - 1
